@@ -37,7 +37,7 @@ import warnings
 class PlenopticamConfig(object):
 
     # static class variables for key parameters
-    lfp_path, cal_path, cal_meta, cal_meth, \
+    lfp_path, cal_path, cal_meta, cal_meth, smp_meth, \
     ptc_leng, \
     ran_refo, \
     opt_cali, opt_vign, opt_lier, opt_cont, opt_colo, opt_awb_, opt_sat_, opt_view, opt_refo, opt_refi, opt_pflu, \
@@ -60,20 +60,14 @@ class PlenopticamConfig(object):
 
         try:
             self.read_params()
-            # test if config parameters present
-            if not self.params.keys():
-                raise FileNotFoundError('Config file could not be loaded')
-            # number of values in loaded config is supposed to equal config constants specified in the tool
-            if not len(self.params.keys()) == len(PARAMS_KEYS):
-                raise PlenopticamError('Config file corrupted')
         except (PlenopticamError, FileNotFoundError):
             self.default_values()
             self.save_params()
 
     def read_params(self, fp=None):
 
-        if not fp:
-            fp = join(self._dir_path, 'cfg.json')
+        # use default path only if file path not provided
+        fp = join(self._dir_path, 'cfg.json') if fp is None else fp
 
         try:
             with open(fp, 'r') as f:
@@ -86,6 +80,13 @@ class PlenopticamConfig(object):
         except FileNotFoundError:
             pass
 
+        # test if config parameters present
+        if not self.params.keys():
+            raise FileNotFoundError('Config file could not be loaded')
+        # number of values in loaded config is supposed to equal config constants specified in the tool
+        if not len(self.params.keys()) == len(PARAMS_KEYS):
+            warnings.warn('Config file corrupted', UserWarning)
+
         return True
 
     def save_params(self, fp=None):
@@ -144,7 +145,11 @@ class PlenopticamConfig(object):
         # construct file path
         fp = self.get_file_path() if fp is None else fp
 
-        self.save_json(fp=fp, **kwargs)
+        # pass kwargs to calibration dictionary (override existing)
+        for kw, arg in list(kwargs.items()):
+            self.calibs[kw] = arg
+
+        self.save_json(fp=fp, **self.calibs)
 
         return True
 
