@@ -26,7 +26,7 @@ from scipy.interpolate import interp1d
 
 from plenopticam import misc
 from plenopticam.lfp_extractor import LfpViewpoints
-from plenopticam.lfp_aligner.lfp_resampler import LfpResampler
+from plenopticam.lfp_aligner.lfp_local_resampler import LfpLocalResampler
 
 
 class HexCorrector(LfpViewpoints):
@@ -39,7 +39,7 @@ class HexCorrector(LfpViewpoints):
 
         if self.cfg.calibs[self.cfg.mic_list] is not None:
             # analyse
-            self.hex_odd = LfpResampler.get_hex_direction(np.asarray(self.cfg.calibs[self.cfg.mic_list]))
+            self.hex_odd = LfpLocalResampler.get_hex_direction(np.asarray(self.cfg.calibs[self.cfg.mic_list]))
         else:
             # reset pattern type to skip hex correction process
             self.cfg.calibs[self.cfg.pat_type] = 'rec'
@@ -136,7 +136,7 @@ class HexCorrector(LfpViewpoints):
             if full_mask[j::2, ...].shape[0] == mask.shape[0]:
                 full_mask[j::2, ...] = mask
             else:
-                full_mask[j::2, ...][:-1] = mask
+                full_mask[j::2, ...][:mask.shape[0], ...] = mask
             misc.save_img_file(full_mask, os.path.join(self.cfg.exp_path, 'hex_filter_mask.png'), tag=True)
 
         # generate image indicating which pixels were treated
@@ -146,7 +146,7 @@ class HexCorrector(LfpViewpoints):
                 if tes[j::2, ...].shape[0] == mask.shape[0]:
                     tes[j::2, :, p][mask[..., p] != 0] = tes.max()
                 else:
-                    tes[j::2, :, p][:-1][mask[..., p] != 0] = tes.max()
+                    tes[j::2, :, p][:mask.shape[0], ...][mask[..., p] != 0] = tes.max()
             tes_out = np.divide(tes, tes.max(), out=np.zeros_like(tes), where=tes != 0)
             misc.save_img_file(tes_out, os.path.join(self.cfg.exp_path, 'ident.png'), tag=True)
 
